@@ -1371,6 +1371,7 @@ end:
   return node;
 }
 
+#if GLIB_CHECK_VERSION (2, 38, 0)
 static xmlNodePtr
 prop_quota_used (PathHandler *handler, PropFind *pf,
                  const gchar *path, GFileInfo *info, xmlNsPtr ns)
@@ -1378,7 +1379,7 @@ prop_quota_used (PathHandler *handler, PropFind *pf,
   gint status = SOUP_STATUS_OK;
   PhodavServer *self = handler->self;
   xmlNodePtr node = xmlNewNode (ns, BAD_CAST "quota-used-bytes");
-  guint64 disk_usage;
+  guint64 disk_usage = 0;
   GError *error = NULL;
   gchar *tmp = NULL;
 
@@ -1405,6 +1406,7 @@ end:
   PROP_SET_STATUS (node, status);
   return node;
 }
+#endif
 
 static void
 prop_add (GList **stat, xmlNodePtr node)
@@ -1418,6 +1420,7 @@ static const struct _PropList
   const gchar *name;
   xmlNodePtr (*func) (PathHandler *, PropFind *, const gchar *, GFileInfo *, xmlNsPtr);
   gboolean need_info;
+  gboolean slow;
 
 } prop_list[] = {
   PROP (resourcetype, 1),
@@ -1431,7 +1434,9 @@ static const struct _PropList
   PROP (supportedlock, 0),
   PROP (lockdiscovery, 0),
   { "quota-available-bytes", prop_quota_available, },
-  { "quota-used-bytes", prop_quota_used, }
+#if GLIB_CHECK_VERSION (2, 38, 0)
+  { "quota-used-bytes", prop_quota_used, FALSE, TRUE, }
+#endif
 };
 
 static xmlNodePtr
@@ -1475,9 +1480,13 @@ propfind_populate (PathHandler *handler, const gchar *path,
     {
       for (i = 0; i < G_N_ELEMENTS (prop_list); i++)
         {
-          if (pf->type != PROPFIND_PROPNAME &&
-              prop_list[i].need_info && !info)
-            continue;
+          if (pf->type != PROPFIND_PROPNAME)
+            {
+              if (prop_list[i].need_info && !info)
+                continue;
+              if (prop_list[i].slow)
+                continue;
+            }
 
           /* perhaps not include the 404? */
           prop_add (&stat, prop_list[i].func (handler, pf, path, info, ns));
